@@ -1,7 +1,7 @@
 /*
  * Formatter function for bytes or lines transferred.
  *
- * Copyright 2024 Andrew Wood
+ * Copyright 2024-2025 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
  */
@@ -20,13 +20,19 @@ pvdisplay_bytecount_t pv_formatter_bytes(pvformatter_args_t args)
 
 	args->display->showing_bytes = true;
 
-	content[0] = '\0';
-
 	if (0 == args->buffer_size)
 		return 0;
 
+	content[0] = '\0';
+
 	/*@-mustfreefresh@ */
-	if (args->state->control.bits && !args->state->control.linemode) {
+	if (args->state->control.numeric) {
+		/* Numeric mode - raw values only, no suffix. */
+		(void) pv_snprintf(content, sizeof(content),
+				   "%lld",
+				   (long long) ((args->state->control.bits ? 8 : 1) *
+						args->state->transfer.transferred));
+	} else if (args->state->control.bits && !args->state->control.linemode) {
 		pv_describe_amount(content, sizeof(content), "%s",
 				   (long double) (args->state->transfer.transferred * 8), "", _("b"),
 				   args->display->count_type);
